@@ -87,20 +87,24 @@ enum Operation {
     Version {
         /// Returns name and version of the primary underlying OpenPGP
         /// toolkit.
-        #[clap(long, conflicts_with("extended"), conflicts_with("sop_spec"))]
+        #[clap(long, conflicts_with("extended"), conflicts_with("sop_spec"), conflicts_with("sopv"))]
         backend: bool,
 
         /// Returns multiple lines of name and version information.
         ///
         /// The first line is the name and version of the SOP
         /// implementation, but the rest have no defined structure.
-        #[clap(long, conflicts_with("backend"), conflicts_with("sop_spec"))]
+        #[clap(long, conflicts_with("backend"), conflicts_with("sop_spec"), conflicts_with("sopv"))]
         extended: bool,
 
         /// Returns the latest version of the SOP spec that is
         /// implemented.
-        #[clap(long, conflicts_with("backend"), conflicts_with("extended"))]
+        #[clap(long, conflicts_with("backend"), conflicts_with("extended"), conflicts_with("sopv"))]
         sop_spec: bool,
+
+        /// Returns "1.0\n" if the sopv subset is implemented.
+        #[clap(long, conflicts_with("backend"), conflicts_with("extended"), conflicts_with("sop_spec"))]
+        sopv: bool,
     },
     /// Emits a list of profiles supported by the identified
     /// subcommand.
@@ -413,26 +417,29 @@ where
     };
 
     match Operation::from_arg_matches(&matches)? {
-        Operation::Version { backend, extended, sop_spec } => {
+        Operation::Version { backend, extended, sop_spec, sopv } => {
             let version = sop.version()?;
-            match (backend, extended, sop_spec) {
-                (false, false, false) => {
+            match (backend, extended, sop_spec, sopv) {
+                (false, false, false, false) => {
                     let v = version.frontend()?;
                     println!("{} {}", v.name, v.version);
                 },
-                (true, false, false) => {
+                (true, false, false, false) => {
                     let v = version.backend()?;
                     println!("{} {}", v.name, v.version);
                 },
-                (false, true, false) => {
+                (false, true, false, false) => {
                     let v = version.frontend()?;
                     println!("{} {}", v.name, v.version);
                     println!("sop-rs {}", env!("CARGO_PKG_VERSION"));
                     println!("{}", version.extended()?);
                 },
-                (false, false, true) => {
+                (false, false, true, false) => {
                     println!("{}", sop.spec_version());
                 },
+                (false, false, false, true) => {
+                    println!("{}", sop.sopv_version()?);
+                },
                 _ => unreachable!("flags are mutually exclusive"),
             }
         },
