@@ -134,7 +134,15 @@ pub trait SOP<'s>: Sized {
     /// implementations.  However, implementations may chose to
     /// override this function to return a more nuanced response.
     fn spec_version(&'s self) -> &'static str {
-        "~draft-dkg-openpgp-stateless-cli-08"
+        "~draft-dkg-openpgp-stateless-cli-10"
+    }
+
+    /// Completeness of the sopv subset
+    ///
+    /// If all the features of the sopv subset are implemented, an
+    /// implementation should return Ok("1.0")
+    fn sopv_version(&'s self) -> Result<&'static str> {
+        Err(Error::UnsupportedOption)
     }
 
     /// Gets version information.
